@@ -98,7 +98,7 @@ impl Localization {
 
     pub fn format_text(&self, id: &str, params: &[(&str, &str)]) -> Result<String, String> {
         if let Some(text_format) = self.find_text_format(id) {
-            match parser::SentenceParser::parse(parser::Rule::sentence, &text_format) {
+            match parser::SentenceParser::parse(parser::Rule::sentence, text_format) {
                 Ok(mut ast) => {
                     let pair = ast.next().unwrap();
                     match pair.as_rule() {
